import fullpage from 'fullpage.js'
import 'fullpage.js/dist/fullpage.css'

function FullPage($timeout) {
  return {
    restrict: 'A',
    scope: {
      options: '=',
    },
    link: function (scope, element) {
      let pageIndex
      let slideIndex
      let afterRender
      let onLeave
      let onSlideLeave
      let fullPageInstance

      if (typeof scope.options === 'object') {
        if (scope.options.afterRender) {
          afterRender = scope.options.afterRender
        }

        if (scope.options.onLeave) {
          onLeave = scope.options.onLeave
        }

        if (scope.options.onSlideLeave) {
          onSlideLeave = scope.options.onSlideLeave
        }
      } else if (typeof scope.options === 'undefined') {
        scope.options = {}
      }

      const destroyFullPage = function () {
        if (fullPageInstance && fullPageInstance.destroy) {
          fullPageInstance.destroy(`all`)
        }
      }

      const rebuild = function () {
        destroyFullPage()

        fullPageInstance = new fullpage(element[0], sanatizeOptions(scope.options))

        if (typeof afterRender === 'function') {
          afterRender()
        }
      }


      const sanatizeOptions = function (options) {
        options.afterRender = afterAngularRender
        options.onLeave = onAngularLeave
        options.onSlideLeave = onAngularSlideLeave

        function afterAngularRender() {
          if (options && options.navigation) {
            element.find('a').removeAttr('href')
          }

          if (pageIndex) {
            $timeout(function () {
              fullPageInstance.silentMoveTo(pageIndex, slideIndex)
            })
          }
        }

        function onAngularLeave(page, next, direction) {
          if (typeof onLeave === 'function' && onLeave(page, next, direction) === false) {
            return false
          }
          pageIndex = next
        }

        function onAngularSlideLeave(anchorLink, page, slide, direction, next) {
          if (typeof onSlideLeave === 'function' && onSlideLeave(anchorLink, page, slide, direction, next) === false) {
            return false
          }
          pageIndex = page
          slideIndex = next
        }

        return options
      }

      const watchNodes = function () {
        return element[0].getElementsByTagName('*').length
      }

      scope.$watch(watchNodes, rebuild)
      scope.$watch('options', rebuild, true)
      element.on('$destroy', destroyFullPage)
    }
  }
}

FullPage.$inject = ['$timeout']

export { FullPage }
