export namespace Functions {
    export function isPWA() {
        return true
        // return (window.matchMedia('(display-mode: standalone)').matches) || (window.navigator['standalone'])
    }

    export function isMobile() {
        return /iPhone|iPad|iPod|Android/i.test(navigator.userAgent)
    }

    export function groupBy(list, keyGetter): any {
        const map = new Map()
        list.forEach((item) => {
            const key = keyGetter(item)
            const collection = map.get(key)
            if (!collection) {
                map.set(key, [item])
            } else {
                collection.push(item)
            }
        })
        return map
    }

    export function isAndroid() {
        const ua = navigator.userAgent.toLowerCase()
        return ua.indexOf('android') > -1
    }

    export function generateLinkWithParams(routeName, params = {}) {
        return Object.keys(params)
            .filter((param) => params[param])
            .reduce((v, param, i) => v + `${(i === 0) ? `?` : '&'}${param}=${params[param]}`, location.origin + location.pathname + `#!/${routeName}`)
    }
    export function enableAndroidIntroduction($state) {
        const isChrome = !!window['chrome']
        return (!Functions.isPWA()
            && Functions.isAndroid()
            && $state.current.name !== 'android-introduction'
            && isChrome)
    }
    export function enableNavigatorNotSupported($state) {
        const isChrome = !!window['chrome']
        return (!Functions.isPWA()
            && Functions.isAndroid()
            && $state.current.name !== 'navigator-not-supported'
            && !isChrome)
    }
    export function checkRouters($state, $timeout) {
        // verifica se o usuário não está com o app instalado e se ele está em um dispositivo android
        // com isso daremos uma experiência para android para que ele consiga instalar o aplicativo
        $timeout(() => {
            // caso esteja em outro navegador que não seja chrome.
            if (Functions.enableNavigatorNotSupported($state)) {
                location.href = location.origin + location.pathname + '#!/navigator-not-supported?redirectTo=' + btoa(location.href)
                return
            }
            // caso esteja no android e ainda não instalado o app.
            if (Functions.enableAndroidIntroduction($state)) {
                location.href = location.origin + location.pathname + '#!/android-introduction?redirectTo=' + btoa(location.href)
                return
            }
        })
    }
    export function getUnique(arr, comp?: string) {
        if (arr.length > 0) {
            const pathArr = function (obj, path) {
                let current = obj
                if (path) {
                    path.split('.').forEach((p) => { current = current[p] })
                }
                return current
            }
            let unique = [arr[0]]
            arr.forEach((arrItem) => {
                let equal = false
                unique.forEach((uniqueItem) => {
                    if (pathArr(uniqueItem, comp) === pathArr(arrItem, comp)) {
                        equal = true
                    }
                })
                if (!equal) {
                    unique.push(arrItem)
                }
            })
            return unique
        }
        return []
    }
    export function calculatePromotionValue(item) {
        return (item.valuePromo * 100) / item.value
    }
    export function getItens(product) {
        return product.itens.reduce((arr, productItem) => {
            const color = productItem.variation ? productItem.variation.find((variation) => variation.type === 'COR') : {}
            const size = productItem.variation ? productItem.variation.find((variation) => variation.type === 'TAMANHO') : {}
            const index = arr.findIndex((arrItem) => arrItem.colors.find((variation) => variation.type === 'COR' && variation.value === color.value) ? true : false)

            size.itemId = product.id

            if (index !== -1) {
                arr[index].sizes = arr[index].sizes || []
                arr[index].sizes.push(size)
                return arr
            }
            if (!productItem.variation) {
                size.qtdValue = productItem.qtdValue
            }
            return arr.concat([{
                name: product.name,
                productId: product.id,
                codeReference: product.codeReference,
                files: productItem.files,
                viewImage: productItem.files[0],
                isGrid: productItem.variation.length > 1,
                valuePromo: productItem.pricePromo,
                value: product.priceNumber,
                colors: [
                    color,
                ],
                sizes: [
                    size,
                ]
            }])
        }, [])
    }

    export function isEmpty(obj) {
        return Object.keys(obj).length === 0
    }

    export function objectAssign(value) {
        return JSON.parse(JSON.stringify(value))
    }
}

