import { IOnInit, merge, copy } from 'angular'
import Swiper from 'swiper/dist/js/swiper.js'
import { PWA } from '../../helpers/pwa'
import { Functions } from '../../helpers/functions'

class AndroidIntroductionPage implements IOnInit {
    private swiper
    private timerBanner: number
    private activeProgress: boolean
    private progressDuration: number
    private step: number
    private alreadyFailed: boolean
    private defferPrompt: any
    private defferPromptError: boolean
    private installed: boolean
    private redirectTo: string
    private link: string

    constructor(public $timeout, public $state, public $stateParams) { }

    $onInit() {
        this.redirectTo = this.$stateParams.redirectTo ? atob(this.$stateParams.redirectTo) : location.origin + location.pathname
        this.step = this.$stateParams.step || 0
        this.alreadyFailed = this.$stateParams.alreadyFailed === 'true'
        this.timerBanner = 5
        this.progressDuration = 10000
        this.createSlides()
        this.createTimer()
        this.syncDefferPrompt()
    }

    async syncDefferPrompt() {
        try {
            const defferPrompt = await PWA.getDefferedPrompt()
            this.$timeout(() => {
                this.defferPrompt = defferPrompt
            })
        } catch (e) {
            this.$timeout(() => this.defferPromptError = true)
        }
    }

    createTimer() {
        const handleTimer = () => {
            if (this.timerBanner > 0) { this.timerBanner-- }
            this.$timeout(() => handleTimer(), 1000)
        }
        this.$timeout(() => handleTimer(), 1000)
    }

    createSlides() {
        this.swiper = new Swiper('.swiper-container', {
            spaceBetween: 30,
            initialSlide: this.step,
            touchRatio: 0,
        })
    }

    onClickFakeInstall() {
        this.activeProgress = true
        this.$timeout(() => {
            location.href = Functions.generateLinkWithParams('android-introduction', merge(copy(this.$stateParams), { step: 1 }))
            location.reload()
        }, this.progressDuration)
    }

    reloadPage() {
        location.href = Functions.generateLinkWithParams('android-introduction', Object.assign(copy(this.$stateParams), { step: 1, alreadyFailed: true }))
        location.reload()
    }

    showDefferPrompt() {
        try {
            this.defferPrompt.prompt()
            this.defferPrompt.userChoice
                .then((choiceResult) => {
                    const accepted = choiceResult.outcome === 'accepted'
                    if (accepted) {
                        this.$timeout(() => this.afterInstall())
                    } else {
                        location.reload()
                    }
                    PWA.deferredPrompt = null
                })
        } catch (e) {
            location.reload()
        }
    }

    afterInstall() {
        this.activeProgress = true
        this.$timeout(() => {
            this.link = this.redirectTo
            this.activeProgress = false
            this.installed = true
        }, this.progressDuration)
    }

    continue() {
        this.$state.go('home')
    }

}

export { AndroidIntroductionPage }
