import { AppService } from '../../services/app.service'
import { Functions } from '../../helpers/functions'
import dragImage from '../../assets/images/drag-icon.jpg'

class CatalogV2Page {
    // dados da organizacao
    private organization
    // dados do catalago
    private catalog
    // categorias disponiveis
    private categories
    // categoria que esta ativa
    private activeCategory
    // produtos da categoria ativa
    private activeProducts
    // produto que esta sendo comprado
    private activeProduct
    // configuracao do fullPageJs
    private fullpageOptions = {
        licenseKey: `B3161FF4-0A4D44C8-94188BFB-E73B4031`,
        navigation: true,
        parallax: true,
    }
    private dragImage
    // fala se vai aparecer o tour e qual o step ele está
    private tour

    constructor(
        public $state,
        public $stateParams,
        public $timeout,
        public appService: AppService) { }


    $onInit() {
        const ignoreTour = localStorage.getItem(`ignore-tour`)
        if (!ignoreTour) {
            this.tour = 1
        }
        this.dragImage = dragImage
        this.loadOrganization()
        this.loadCatalog()
        this.handleVibrantColor()
    }

    finishTour() {
        delete this.tour
        localStorage.setItem(`ignore-tour`, 'true')
    }

    // busca a cor mais usada em uma foto
    async handleVibrantColor() {
        // const result = await analyze(
        //     'https://s3.sa-east-1.amazonaws.com/zaap.images/uploads%2F8B458F07C7C9038A4D4B4BC49544DE46.png',
        //     { ignore: ['rgb(255,255,255)', 'rgb(0,0,0)'], scale: 0.6 })
        // const metaThemeColor = document.querySelector(`meta[name=theme-color]`)
        // const parseColor = (color) => {
        //     var arr = []; color.replace(/[\d+\.]+/g, function (v) { arr.push(parseFloat(v)); });
        //     return {
        //         hex: "#" + arr.slice(0, 3).map(toHex).join(""),
        //         opacity: arr.length == 4 ? arr[3] : 1
        //     };
        // }
        // const toHex = (int) => {
        //     var hex = int.toString(16);
        //     return hex.length == 1 ? "0" + hex : hex;
        // }
        // metaThemeColor.setAttribute(`content`, parseColor(result[0].color).hex)
    }

    async loadOrganization() {
        const response = await this.appService.getOrganizationById(this.$stateParams.name)
        this.$timeout(() => this.organization = response.data())
    }

    async loadCatalog() {
        const response = await this.appService.getCatalogById(this.$stateParams)
        this.$timeout(() => {
            this.catalog = response
            this.processProduts()
        })
    }

    processProduts() {
        this.categories = []
        const groups = Functions.groupBy(this.catalog.products, (product) => product.productType.name)
        groups.forEach((products, productType) => {
            this.categories.push({
                name: productType,
                products,
            })
        })
        this.setActiveCategory(this.categories[0].name)
    }

    setActiveCategory(category) {
        this.activeCategory = category
        this.activeProducts = this.categories.find((c) => c.name === category).products
    }

    getColorsLabel(itens) {
        const colors = []
        itens.forEach((item) => {
            item.variation.forEach((variation) => {
                if (!colors.find((c) => variation.value === c.value) && variation.type == `COR`) {
                    colors.push(variation)
                }
            })
        })
        return colors.map((c) => c.label).join(`, `)
    }

    getSizesLabel(itens) {
        const sizes = []
        itens.forEach((item) => {
            item.variation.forEach((variation) => {
                if (!sizes.find((c) => variation.value === c.value) && variation.type == `TAMANHO`) {
                    sizes.push(variation)
                }
            })
        })
        return sizes.map((c) => c.value).join(`, `)
    }

    setActiveProduct(product) {
        this.activeProduct = product
    }

    showDevelopMessage() {
        alert('Essa funcionalidade está em desenvolvimento.')
    }

    addToShoppingCart(product) {
        delete this.activeProduct
    }

    getTotalItensSale(product) {
        const { sale } = product
        if (!sale) {
            return 0
        }
        return Object.keys(sale).reduce((v, size) => {
            return v + Object.keys(sale[size] || {}).reduce((v, color) => {
                return v + (sale[size][color] || 0)
            }, 0) || 0
        }, 0)
    }

    alreadyAdded(product) {
        return (this.getTotalItensSale(product) > 0)
    }

}

export { CatalogV2Page }
