import './product-select-details.scss'
import template from './product-select-details.html'

class ProductSelectDetailsController {
    private optionsSlider: any
    private ngModel: any
    private unwatch: any
    private colors: any
    private sizes: any
    private onClickButton: Function
    private productDTO
    private activeColor

    constructor(public $scope, public $element, public $timeout) { }

    $onInit() {
        this.optionsSlider = {
            floor: 0,
            ceil: 10,
        }
        this.unwatch = this.$scope.$watch(`$ctrl.ngModel`, (product) => {
            const nav: any = document.querySelector(`#fp-nav`)
            if (product) {
                if (nav) {
                    nav.style.display = `none`
                }
                this.colors = this.getVariationByType(product.itens, `COR`)
                this.sizes = this.getVariationByType(product.itens, `TAMANHO`)
                this.activeColor = this.colors[0]
            } else {
                if (nav) {
                    nav.style.display = `block`
                }
            }
        })
    }

    $onDestroy() {
        if (this.unwatch) { this.unwatch() }
    }

    getVariationByType(itens, type) {
        const colors = []
        itens.forEach((item) => {
            item.variation.forEach((variation) => {
                if (!colors.find((c) => variation.value === c.value) && variation.type == type) {
                    colors.push(variation)
                }
            })
        })
        return colors
    }

    initializeValues(size, color) {
        this.$timeout(() => {
            this.ngModel.sale = this.ngModel.sale || {}
            this.ngModel.sale[size.value] = this.ngModel.sale[size.value] || {}
            this.ngModel.sale[size.value][color.value] = this.ngModel.sale[size.value][color.value] || 0
        })
    }

    validadeReference(reference) {
        return reference != null && reference != ''
    }

    createContentSlider(size) {
        this.$timeout(() => {
            const elm: any = document.querySelector(`.rzslider[size="${size}"] span.rz-pointer.rz-pointer-min`)
            if (elm) {
                elm.setAttribute('data-content', size)
            }
        })
    }

    clickBtn() {
        if (this.onClickButton) {
            this.onClickButton({ product: this.ngModel })
        }
    }



}

const productSelectDetails = {
    bindings: {
        expanded: '=?',
        ngModel: '=?',
        colors: '=?',
        enableColors: '=?',
        onClickButton: '&?',
        buttonText: '@?'
    },
    controller: ProductSelectDetailsController,
    template: template,
}

ProductSelectDetailsController['$inject'] = ['$scope', '$element', '$timeout']

export { productSelectDetails }
