import { IOnInit, element } from 'angular'
import { Functions } from '../../helpers/functions'
import { AppService } from '../../services/app.service'
import moment from 'moment'
import { Catalog } from '../../interfaces/catalog'
import { Group } from '../../interfaces/group'
import Swiper from 'swiper/dist/js/swiper.js'
import { StateService } from '../../services/state.service'
import { SessionStorage } from '../../helpers/session-storage'
import firebase from 'firebase'

class CatalogPage implements IOnInit {
    private catalog: Catalog
    private isValidCatalog: boolean = true
    private loadingCatalog: boolean
    private groups: Array<Group> = []
    private selectedProducts: Array<any>
    private swiper
    private scrollHorizontally

    constructor(
        public $state,
        public $timeout,
        public $stateParams,
        public appService: AppService,
        public stateService: StateService,
        public ngMeta
    ) {
        this.ngMeta.setDefaultTag('description', 'AOSUhdauisdhasiuhdiuashduiasihdasudhauosdha')
        this.ngMeta.setDefaultTag('title', 'Xablau')
    }

    $onInit() {
        window['prerenderReady'] = true
        // const unsubscribe = firebase.auth().onAuthStateChanged((user) => {
        //    if (!user) {

        //    }
        //     unsubscribe()
        // })
        Functions.checkRouters(this.$state, this.$timeout)
        this.searchCatalog()
        this.selectedProducts = JSON.parse(sessionStorage.getItem('shoppingCart'))

    }

    $onDestroy() {
        this.swiper.destroy()
    }

    searchCatalog() {
        this.loadingCatalog = false
        this.appService
            .getCatalogById(this.$stateParams)
            .then((catalog: Catalog) => {
                this.isValidCatalog = moment(catalog.expiredAt).valueOf() > new Date().getTime()
                this.$timeout(() => {
                    this.catalog = catalog
                    this.processGroup()
                })

            })
            .catch(() => {
                this.isValidCatalog = false
            })
            .finally(() => {
                this.loadingCatalog = true
            })
    }

    processGroup() {
        this.groups = Functions.getUnique(this.catalog.products.map((product: any) => product.productType.name))
            .map((groupName) => {
                return {
                    name: groupName,
                    products: this.catalog.products.filter((product: any) => product.productType.name === groupName)
                }
            })
    }

    createSwiperGroup(groupName) {
        this.$timeout(() => {
            this.swiper = new Swiper(`.swiper-container[group=' ${groupName} ']`, {
                effect: 'coverflow',
                centeredSlides: false,
                slidesPerView: 2.2,
                spaceBetween: 14,
                activeIndex: 1,
                coverflowEffect: {
                    rotate: 0,
                    stretch: 0,
                    depth: 0,
                    modifier: 1,
                    slideShadows: false,
                },
            })
        })
    }

    containsPromotion(itens) {
        return itens.filter((item) => item.valuePromo).length > 0
    }

    calculatePromotion(itens) {
        let value = 0
        let index
        itens.forEach((item, i) => {
            if (item.valuePromo > value) {
                value = item.valuePromo
                index = i
            }
        })
        return `-${Functions.calculatePromotionValue(itens[index]).toFixed(0)}%`
    }

    goProductDetails(group, productId) {
        SessionStorage.setItem('productGroup', group.products)
        this.stateService.go(`product-details`, { id: productId })
    }

}

export { CatalogPage }
