import { IOnInit } from 'angular'
import { Functions } from '../../helpers/functions'
import { AppService } from '../../services/app.service'
import { Product } from '../../interfaces/product'
import Swiper from 'swiper/dist/js/swiper.js'
import { SessionStorage } from '../../helpers/session-storage'
import { StateService } from '../../services/state.service'

class ProductDetailsPage implements IOnInit {
    private products: Array<Product>
    private loadingProduct: boolean
    private productsDto: Array<any> = []
    private colors: Array<any> = []
    private activeIndex: number = 0
    private activeItemIndex: number = 0
    private swiper: any
    private activeSelectSize: boolean
    private selectedValues: Array<any> = []
    private shoppingCart: Array<any>

    constructor(
        public $state,
        public $timeout,
        public $stateParams,
        public appService: AppService,
        public stateService: StateService
    ) {
    }

    async $onInit() {
        Functions.checkRouters(this.$state, this.$timeout)
        await this.searchProduct()
        await this.createSwiper()
        this.setActiveAllProducts()
        this.shoppingCart = SessionStorage.getItem('shoppingCart') || []

    }

    createSwiper() {
        this.$timeout(() => {
            const index = (this.products || []).findIndex((product) => product.id === this.$stateParams.id)
            this.getColorsByItens(this.productsDto[index])
            this.swiper = new Swiper('.swiper-container', {
                effect: 'coverflow',
                centeredSlides: true,
                slidesPerView: 1,
                spaceBetween: 50,
                activeIndex: index >= 0 ? index : 0,
                initialSlide: index >= 0 ? index : 0,
                coverflowEffect: {
                    rotate: 0,
                    stretch: 0,
                    depth: 200,
                    modifier: 1,
                    slideShadows: false,
                },
                limite: 500
            })
            this.activeIndex = index >= 0 ? index : 0
            this.swiper.on('touchStart', (e) => {
                this.swiper.allowTouchMove = !this.containsInfoClass(e.path)
            })
            this.swiper.on('slideChange', (i) => {
                this.$timeout(() => {
                    this.activeIndex = this.swiper.activeIndex
                    this.getColorsByItens(this.productsDto[this.swiper.activeIndex])
                })
            })
        })
    }

    containsInfoClass(divs) {
        return divs.filter((div) => div.className === 'info').length > 0
    }

    searchProduct() {
        return new Promise((resolve, reject) => {
            this.$timeout(() => {
                const products = SessionStorage.getItem('productGroup')
                this.products = products
                products.forEach((product) => {
                    this.productsDto.push(Functions.getItens(product))
                })
                resolve(this.productsDto)
            })
        })

    }

    getColorsByItens(itens) {
        this.colors = []
        itens.forEach(item => {
            if (!Functions.isEmpty(item.colors[0])) {
                this.colors.push(item.colors[0])
            }
        })
    }

    getActiveColor(colorValue) {
        if (colorValue) {
            const product = this.productsDto[this.activeIndex].find((prod) => prod.colors[0].value === colorValue) || {}
            return product.active
        }
    }

    setActiveColorProduct(colorValue) {
        this.productsDto[this.activeIndex].forEach(prod => {
            prod.active = false
        })
        const product = this.productsDto[this.activeIndex].find((prod) => prod.colors[0].value === colorValue)
        const index = this.productsDto[this.activeIndex].findIndex((a) => JSON.stringify(a) === JSON.stringify(product))
        product.active = true
        this.activeItem(index)
    }

    getProductActive(products) {
        const result = products.find((product) => product.active)
        if (!result) {
            return products[0]
        }
        return result
    }

    getProductActiveImage(products) {
        const product = this.getProductActive(products)
        return product.viewImage
    }

    getProductActiveImages(products) {
        const product = products[0]
        return product.files
    }

    getProductActiveReference(products) {
        const product = this.getProductActive(products)
        return product.codeReference != '' && product.codeReference != null ? product.codeReference : false
    }

    getProductActiveName(products) {
        const product = this.getProductActive(products)
        return product.name
    }

    getProductActiveSizes(products) {
        const product = this.getProductActive(products)
        return product.sizes
    }

    setActiveAllProducts() {
        this.productsDto.forEach((prod) => {
            prod[0].active = true
        })
    }

    activeSelectSizes(products) {
        const index = products.findIndex((product) => product.active)
        this.activeSelectSize = true
        this.activeItem(index)
    }

    activeItem(index) {
        this.activeItemIndex = index
    }

    removeSelect() {
        delete this.activeSelectSize
    }

    addToShoppingCart() {
        const products = this.productsDto[this.activeIndex]
        products.forEach((prod) => {
            let product = Functions.objectAssign(prod)
            product.sizes = product.sizes.filter((size) => size.qtdValue > 0)
            if (product.sizes.length > 0) {
                this.shoppingCart.push(product)
            }
        })
        this.activeSelectSize = false
        this.saveSelectedProducts()
    }

    saveSelectedProducts() {
        sessionStorage.setItem('shoppingCart', JSON.stringify(this.shoppingCart))
    }

    openImage(url) {
        this.appService.openProductImage(url)
    }

    activeImage(data, arr) {
        arr.forEach((product) => {
            product.viewImage = data
        })
    }

}

export { ProductDetailsPage }
