import { Catalog } from '../interfaces/catalog'
import { Product } from '../interfaces/product'
import viewModal from '../pages/product-details/modals/view-image/view-image.html'
import { ViewImageController } from '../pages/product-details/modals/view-image/view-image'
import firebase from 'firebase'

class AppService {
  private db

  constructor(public $http, public $uibModal) {
    this.db = firebase.firestore()
  }

  getOrganizationById(id: string) {
    return this.db.collection('organizations').doc(id).get()
  }

  saveOrder(organization, order) {
    return this.db.collection('organizations').doc(organization).collection('orders').add(order)
  }

  capture(body) {
    return this.$http.post(`https://us-central1-zaap-admin.cloudfunctions.net/capture`, body)
  }

  openProductImage(url) {
    this.$uibModal.open({
      animation: true,
      template: viewModal,
      controller: ViewImageController,
      backdrop: 'static',
      size: 'lg',
      windowClass: 'view-image',
      controllerAs: '$ctrl',
      resolve: {
        imageUrl: () => url,
      }
    })
  }

  /* tslint:disable */
  async getCatalogById(stateParams): Promise<any> {
    return new Promise((resolve, reject) => {
      this.db
        .collection('organizations')
        .doc(stateParams.name)
        .collection('catalogs')
        .doc(stateParams.catalogId)
        .get()
        .then((response) => {
          if (response.exists) {
            resolve(response.data())
          } else {
            reject()
          }
        })
    })
  }

}

export { AppService }
